@@ -18,4 +18,8 @@ class BootcampDSC:
         self.gambar = Image.open(urlopen('https://i.ibb.co/HYj0Bcr/inherit.jpg'))
         return self.gambar
 
+    def BMIIllustration(self):
+        self.gambar = Image.open(urlopen('https://ukurandansatuan.com/wp-content/uploads/2016/07/uds-rumus-menghitung-BMI-400p.jpg'))
+        return self.gambar
+
 
